==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/request/CascadegrantrevokeaccessrecordstrackerRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Cascadegrantrevokeaccessrecordstracker;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.FileattachmentCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

@JsonIgnoreType
public class CascadegrantrevokeaccessrecordstrackerRequest extends EntityRequest<Cascadegrantrevokeaccessrecordstracker> {

    public CascadegrantrevokeaccessrecordstrackerRequest(ContextPath contextPath, Optional<Object> value) {
        super(Cascadegrantrevokeaccessrecordstracker.class, contextPath, SchemaInfo.INSTANCE, value);
    }

    public SyncerrorCollectionRequest cascadegrantrevokeaccessrecordstracker_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest cascadegrantrevokeaccessrecordstracker_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest cascadegrantrevokeaccessrecordstracker_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest cascadegrantrevokeaccessrecordstracker_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest cascadegrantrevokeaccessrecordstracker_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest cascadegrantrevokeaccessrecordstracker_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest cascadegrantrevokeaccessrecordstracker_FileAttachments() {
        return new FileattachmentCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest cascadegrantrevokeaccessrecordstracker_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

    public CascadegrantrevokeaccessversiontrackerRequest syncTrackerId() {
        return new CascadegrantrevokeaccessversiontrackerRequest(contextPath.addSegment("SyncTrackerId"), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.49-sources.jar: microsoft/dynamics/crm/entity/request/CascadegrantrevokeaccessrecordstrackerRequest.java <==
package microsoft.dynamics.crm.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Cascadegrantrevokeaccessrecordstracker;
import microsoft.dynamics.crm.entity.collection.request.AsyncoperationCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.BulkdeletefailureCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.DuplicaterecordCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.FileattachmentCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.MailboxtrackingfolderCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.PrincipalobjectattributeaccessCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.ProcesssessionCollectionRequest;
import microsoft.dynamics.crm.entity.collection.request.SyncerrorCollectionRequest;

@JsonIgnoreType
public class CascadegrantrevokeaccessrecordstrackerRequest extends EntityRequest<Cascadegrantrevokeaccessrecordstracker> {

    public CascadegrantrevokeaccessrecordstrackerRequest(ContextPath contextPath, Optional<Object> value) {
        super(Cascadegrantrevokeaccessrecordstracker.class, contextPath, value);
    }

    public SyncerrorCollectionRequest cascadegrantrevokeaccessrecordstracker_SyncErrors() {
        return new SyncerrorCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest cascadegrantrevokeaccessrecordstracker_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest cascadegrantrevokeaccessrecordstracker_AsyncOperations() {
        return new AsyncoperationCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest cascadegrantrevokeaccessrecordstracker_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest cascadegrantrevokeaccessrecordstracker_ProcessSession() {
        return new ProcesssessionCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest cascadegrantrevokeaccessrecordstracker_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public FileattachmentCollectionRequest cascadegrantrevokeaccessrecordstracker_FileAttachments() {
        return new FileattachmentCollectionRequest(
                        contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_FileAttachments"), Optional.empty());
    }

    public FileattachmentRequest cascadegrantrevokeaccessrecordstracker_FileAttachments(String fileattachmentid) {
        return new FileattachmentRequest(contextPath.addSegment("cascadegrantrevokeaccessrecordstracker_FileAttachments").addKeys(new NameValue(fileattachmentid.toString())), Optional.empty());
    }

    public CascadegrantrevokeaccessversiontrackerRequest syncTrackerId() {
        return new CascadegrantrevokeaccessversiontrackerRequest(contextPath.addSegment("SyncTrackerId"), Optional.empty());
    }

}
